@@ -58,7 +58,11 @@ void messagef(GtkWidget *parent, char *title, const char *fmt, ...);
 
 #include "canvas.h"
 
-typedef struct appdata {
+#ifdef USE_HILDON
+#include "dbus.h"
+#endif
+
+typedef struct appdata_s {
 #ifdef USE_HILDON
   HildonProgram *program;
   HildonWindow *window;
@@ -80,11 +84,16 @@ typedef struct appdata {
   struct project_s *project;
   struct iconbar_s *iconbar;
   struct icon_s *icon;
+  struct presets_item_s *presets;
 
   /* menu items to be enabled and disabled every now and then */
   gboolean gps_enabled;
   struct gps_state_s *gps_state;
 
+#ifdef USE_HILDON
+  dbus_mm_pos_t mmpos;
+#endif
+
   struct {
     char *import_path;
     GtkWidget *menu_item_import;
@@ -115,5 +124,6 @@ typedef struct appdata {
 #include "track.h"
 #include "gps.h"
 #include "wms.h"
+#include "josm_presets.h"
 
 #endif // APPDATA_H
