@@ -295,12 +295,8 @@ void diff_restore_node(xmlDoc *doc, xmlNodePtr node_node, osm_t *osm) {
     node->pos.lat = pos->lat;
     node->pos.lon = pos->lon;
     
-    /* create utm coordinates */
-    utm_t utm;
-    utm_pos2utm(&node->pos, &utm, &osm->bounds->center);
-    node->lpos.x =  utm.easting  - osm->bounds->center.easting;
-    node->lpos.y = -utm.northing + osm->bounds->center.northing;
-    
+    pos2lpos(osm->bounds, &node->pos, &node->lpos);
+
     g_free(pos);
   }
   
