@@ -19,14 +19,6 @@
 
 #include "appdata.h"
 
-typedef struct {
-  appdata_t *appdata;
-  GtkWidget *dialog, *view;
-  GtkListStore *store;
-  GtkWidget *but_add, *but_remove, *but_edit;
-  tag_t **tag;
-} tag_context_t;
-
 enum {
   TAG_COL_KEY = 0,
   TAG_COL_VALUE,
@@ -48,13 +40,16 @@ view_selection_func(GtkTreeSelection *selection, GtkTreeModel *model,
       tag_t *tag;
       gtk_tree_model_get(model, &iter, TAG_COL_DATA, &tag, -1);
 
-      /* you just cannot delete or edit the "created_by" tag */
-      if(strcasecmp(tag->key, "created_by") == 0) {
-	gtk_widget_set_sensitive(context->but_remove, FALSE);
-	gtk_widget_set_sensitive(context->but_edit, FALSE);
-      } else {
-	gtk_widget_set_sensitive(context->but_remove, TRUE);
-	gtk_widget_set_sensitive(context->but_edit, TRUE);
+      if(context->but_remove && context->but_edit) {
+
+	/* you just cannot delete or edit the "created_by" tag */
+	if(strcasecmp(tag->key, "created_by") == 0) {
+	  gtk_widget_set_sensitive(context->but_remove, FALSE);
+	  gtk_widget_set_sensitive(context->but_edit, FALSE);
+	} else {
+	  gtk_widget_set_sensitive(context->but_remove, TRUE);
+	  gtk_widget_set_sensitive(context->but_edit, TRUE);
+	}
       }
     }
   }
@@ -207,6 +202,23 @@ static void on_tag_add(GtkWidget *button, tag_context_t *context) {
 		       OSM_FLAG_DIRTY, 0);
 }
 
+void info_tags_replace(tag_context_t *context, tag_t *tag) {
+  map_item_set_flags(&context->appdata->map->selected, OSM_FLAG_DIRTY, 0);
+
+  gtk_list_store_clear(context->store);
+
+  GtkTreeIter iter;
+  while(tag) {
+    gtk_list_store_append(context->store, &iter);
+    gtk_list_store_set(context->store, &iter,
+		       TAG_COL_KEY, tag->key,
+		       TAG_COL_VALUE, tag->value,
+		       TAG_COL_DATA, tag,
+		       -1);
+    tag = tag->next;
+  }
+}
+
 static GtkWidget *tag_widget(tag_context_t *context) {
   GtkWidget *vbox = gtk_vbox_new(FALSE,3);
   context->view = gtk_tree_view_new();
@@ -264,6 +276,10 @@ static GtkWidget *tag_widget(tag_context_t *context) {
   /* ------- button box ------------ */
 
   GtkWidget *hbox = gtk_hbox_new(TRUE,3);
+
+  GtkWidget *presets = josm_presets_select(context->appdata, context);
+  gtk_box_pack_start_defaults(GTK_BOX(hbox), presets);
+
   context->but_add = gtk_button_new_with_label(_("Add..."));
   gtk_box_pack_start_defaults(GTK_BOX(hbox), context->but_add);
   gtk_signal_connect(GTK_OBJECT(context->but_add), "clicked",
@@ -281,6 +297,7 @@ static GtkWidget *tag_widget(tag_context_t *context) {
   gtk_signal_connect(GTK_OBJECT(context->but_remove), "clicked",
 		     GTK_SIGNAL_FUNC(on_tag_remove), context);
 
+
   gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
   return vbox;
 }
@@ -356,7 +373,11 @@ void info_dialog(appdata_t *appdata) {
     label = gtk_label_new(pos_str);
     gtk_table_attach_defaults(GTK_TABLE(table),  label, 1, 2, 1, 2);
   }
-    
+
+  /* ------------------- presets button -------------------- */
+  //  gtk_table_attach_defaults(GTK_TABLE(table),
+  //		    josm_presets_select(appdata, context), 0, 2, 2, 3);
+
   gtk_box_pack_start(GTK_BOX(GTK_DIALOG(context->dialog)->vbox), table, 
 		     FALSE, FALSE, 0);
 
