@@ -364,7 +364,7 @@ void cleanup(appdata_t *appdata) {
 
   /* save a dirty project file */
   if(appdata->project && appdata->project->dirty)
-    project_save(appdata, appdata->project);
+    project_save(GTK_WIDGET(appdata->window), appdata->project);
 
   map_remove_bg_image(appdata->map);
 
@@ -372,6 +372,8 @@ void cleanup(appdata_t *appdata) {
 
   curl_global_cleanup();
 
+  josm_presets_clear(appdata->presets);
+
   icon_free_all(appdata);
 
   gps_release(appdata);
@@ -455,6 +457,8 @@ int main(int argc, char *argv[]) {
 					 VERSION, TRUE, NULL);
   if(appdata.osso_context == NULL) 
     fprintf(stderr, "error initiating osso context\n");
+
+  dbus_register(&appdata);
 #endif
 
 #ifdef USE_HILDON
@@ -507,23 +511,23 @@ int main(int argc, char *argv[]) {
 
   gtk_widget_show_all(GTK_WIDGET(appdata.window));
 
+  appdata.presets = josm_presets_load();
+
   /* -------------- load the project ------------- */
 
-  appdata.project = project_open(&appdata, "test");
-  if(!appdata.project) {
+  char *proj_name = project_select(&appdata);
+  if(!proj_name) {
     cleanup(&appdata);
     return 0;
   }    
 
-  printf("loading osm\n");
-  appdata.osm = osm_parse(appdata.project->osm);
-  if(!appdata.osm) {
-    errorf(GTK_WIDGET(appdata.window), _("Parsing of OSM data failed!"));
+  if(!project_open(&appdata, proj_name)) {
+    g_free(proj_name);
     cleanup(&appdata);
     return 0;
-  }
+  }    
 
-  printf("parsing ok\n");
+  g_free(proj_name);
 
   if(!osm_sanity_check(GTK_WIDGET(appdata.window), appdata.osm)) {
     cleanup(&appdata);
@@ -541,6 +545,12 @@ int main(int argc, char *argv[]) {
 
   wms_load(&appdata);
 
+  /* give main window a new name */
+  char *str = g_strdup_printf("OSM2Go - %s", appdata.project->name);
+  gtk_window_set_title(GTK_WINDOW(appdata.window), str);
+  g_free(str);
+
+
   /* ------------ jump into main loop ---------------- */
 
   gtk_main();
