@@ -183,7 +183,7 @@ void osm_tag_free(tag_t *tag) {
   g_free(tag);
 }
 
-static void osm_tags_free(tag_t *tag) {
+void osm_tags_free(tag_t *tag) {
   while(tag) {
     tag_t *next = tag->next;
     osm_tag_free(tag);
@@ -498,6 +498,7 @@ void osm_relations_dump(relation_t *relation) {
       case ILLEGAL:
       case NODE_ID:
       case WAY_ID:
+      case RELATION_ID:
 	break;
 
       case NODE:
@@ -511,6 +512,12 @@ void osm_relations_dump(relation_t *relation) {
 	printf(" Member: Way, id = %lu, role = %s\n", 
 	       member->way->id, member->role);
 	break;
+
+      case RELATION:
+	if(member->relation)
+	printf(" Member: Relation, id = %lu, role = %s\n", 
+	       member->relation->id, member->role);
+	break;
       }
 
       member = member->next;
@@ -533,8 +540,9 @@ static member_t *osm_parse_osm_relation_member(osm_t *osm,
   member->type = ILLEGAL;
 
   if((prop = (char*)xmlGetProp(a_node, (unsigned char*)"type"))) {
-    if(strcasecmp(prop, "way") == 0)       member->type = WAY;
-    else if(strcasecmp(prop, "node") == 0) member->type = NODE;
+    if(strcasecmp(prop, "way") == 0)           member->type = WAY;
+    else if(strcasecmp(prop, "node") == 0)     member->type = NODE;
+    else if(strcasecmp(prop, "relation") == 0) member->type = RELATION;
     xmlFree(prop);
   }
 
@@ -570,8 +578,21 @@ static member_t *osm_parse_osm_relation_member(osm_t *osm,
       }
       break;
 
+    case RELATION:
+      /* search matching relation */
+      member->relation = osm->relation;
+      while(member->relation && member->relation->id != id)
+	member->relation = member->relation->next;
+
+      if(!member->relation) {
+	member->type = NODE_ID;
+	member->id = id;
+      }
+      break;
+
     case WAY_ID:
     case NODE_ID:
+    case RELATION_ID:
       break;
     }
 
