@@ -96,30 +96,13 @@ typedef struct way_chain {
   struct way_chain *next;
 } way_chain_t;
 
-typedef enum {
-  ILLEGAL=0, NODE, WAY, NODE_ID, WAY_ID
-} type_t;
-
-typedef struct member_s {
-  type_t type; 
-  char   *role;
-
-  union {
-    node_t *node;
-    way_t *way;
-    item_id_t id;
-  };
-
-  struct member_s *next;
-} member_t;
-
 typedef struct relation_s {
   item_id_t id;
   user_t *user;
   gboolean visible;
   time_t time;
   tag_t *tag;
-  member_t *member;
+  struct member_s *member;
   int flags;
 
   struct relation_s *next;
@@ -130,6 +113,24 @@ typedef struct relation_chain_s {
   struct relation_chain_s *next;
 } relation_chain_t;
 
+typedef enum {
+  ILLEGAL=0, NODE, WAY, RELATION, NODE_ID, WAY_ID, RELATION_ID
+} type_t;
+
+typedef struct member_s {
+  type_t type; 
+  char   *role;
+
+  union {
+    node_t *node;
+    way_t *way;
+    relation_t *relation;
+    item_id_t id;
+  };
+
+  struct member_s *next;
+} member_t;
+
 typedef struct osm_s {
   bounds_t *bounds;   // original bounds as they appear in the file
   user_t *user;
@@ -158,6 +159,7 @@ void osm_node_dump(node_t *node);
 void osm_way_dump(way_t *way);
 
 void osm_tag_free(tag_t *tag);
+void osm_tags_free(tag_t *tag);
 void osm_node_chain_free(node_chain_t *node_chain);
 
 gboolean osm_node_in_way(way_t *way, node_t *node);
