@@ -150,8 +150,7 @@ static gint wait_dialog_destroy_event(GtkWidget *widget, gpointer data) {
   return FALSE;
 }
 
- gboolean osm_download(GtkWidget *parent, appdata_t *appdata, 
-		       project_t *project) {
+ gboolean osm_download(GtkWidget *parent, project_t *project) {
   printf("download ...\n");
 
   /* ------------ busy dialog -------------- */
@@ -665,7 +664,7 @@ void osm_upload(appdata_t *appdata, osm_t *osm, project_t *project) {
   project->password = g_strdup(gtk_entry_get_text(GTK_ENTRY(pentry)));
 
   gtk_widget_destroy(dialog);
-  project_save(appdata, project);
+  project_save(GTK_WIDGET(appdata->window), project);
 
   /* osm upload itself also has a gui */
   osm_upload_context_t *context = g_new0(osm_upload_context_t, 1);
@@ -724,7 +723,7 @@ void osm_upload(appdata_t *appdata, osm_t *osm, project_t *project) {
     appendf(&context->log, _("Server data has been modified.\n"));
     appendf(&context->log, _("Downloading updated osm data ...\n"));
 
-    if(osm_download(context->dialog, appdata, project)) {
+    if(osm_download(context->dialog, project)) {
       appendf(&context->log, _("Download successful!\n"));
       appendf(&context->log, _("The map will be reloaded.\n"));
       project->data_dirty = FALSE;
@@ -732,7 +731,7 @@ void osm_upload(appdata_t *appdata, osm_t *osm, project_t *project) {
     } else
       appendf(&context->log, _("Download failed!\n"));
 
-    project_save(appdata, project);
+    project_save(context->dialog, project);
 
     if(reload_map) {
       /* this kind of rather brute force reload is useful as the moment */
