@@ -69,7 +69,7 @@ typedef struct {
 typedef struct {
   char *server;
   char *path;
-  gint width, height, scale;
+  gint width, height;
 
   wms_service_t *service;
   wms_cap_t *cap;  
@@ -424,16 +424,12 @@ void wms_setup_extent(project_t *project, wms_t *wms) {
 
   wms->width = lmax.x - lmin.x;
   wms->height = lmax.y - lmin.y;
-  wms->scale = 1;
 
-  while((wms->width > 2048) || (wms->height > 2048)) {
-    wms->width >>= 1;
-    wms->height >>= 1;
-    wms->scale <<= 1;
-  }
+  if(wms->width > 2048)  wms->width = 2048;
+  if(wms->height > 2048) wms->height = 2048;
 
-  printf("WMS: required image size = %dx%d, scale = %d\n", 
-	 wms->width, wms->height, wms->scale);
+  printf("WMS: required image size = %dx%d\n", 
+	 wms->width, wms->height);
 }
 
 /* --------------- freeing stuff ------------------- */
